@@ -1,8 +1,31 @@
+# ------------------------------------------------------------------
+# Petal::Hash - Context for petal objects
+# ------------------------------------------------------------------
+# Author: Jean-Michel Hiver
+# Description: This class manages the context objects, which holds
+# objects which are accessable from the template.
+# ------------------------------------------------------------------
+package Petal::Hash_Repeat;
+use strict;
+use warnings;
+
+our $CUR = undef;
+our $MAX = undef;
+
+sub number { $CUR + 1 }
+sub index  { $CUR }
+sub even   { not $CUR % 2 }
+sub odd    { $CUR % 2 }
+sub start  { not $CUR }
+sub end    { $CUR == $MAX }
+sub inner  { $CUR and $CUR < $MAX }
+
+
 package Petal::Hash;
-use MKDoc::XML::Encode;
 use strict;
 use warnings;
 use Carp;
+use Petal::XML_Encode_Decode;
 
 our $MODIFIERS = {};
 
@@ -94,6 +117,7 @@ sub new
 	bless { @_ }, $thing;
     
     $self->{__petal_hash_cache__}  = {};
+    $self->{repeat} = bless {}, 'Petal::Hash_Repeat';
     return $self;
 }
 
@@ -139,13 +163,22 @@ sub __FETCH
 	my $res = $self->fetch ($key);
 	if (defined $res and not ref $res)
 	{
-	    $res = MKDoc::XML::Encode->process ($res);
+	    $res = $self->_xml_encode ($res);
 	}
 	return $res;
     }
 }
 
 
+# encodes the 4 xml entities &amp; &lt; &gt; and &quot;.
+sub _xml_encode
+{
+    my $self = shift;
+    my $data = join '', @_;
+    return Petal::XML_Encode_Decode::encode ($data);
+}
+
+
 # this method fetches a Petal expression and returns it
 # without XML encoding. FETCH is basically a wrapper around
 # fetch() which looks for the special keyword 'structure'.
@@ -168,9 +201,9 @@ sub _fetch_mod
 {
     my $self  = shift;
     my $key   = shift;
-    my ($mod) = $key =~ /^([A-Za-z0-9_-]+?\:).*/;
+    my ($mod) = $key =~ /^(\S+?\:).*/;
     defined $mod || return 'var:';
-    return $mod;
+    return (defined $MODIFIERS->{$mod}) ? $mod : 'var:';
 }
 
 
